from __future__ import annotations

from prettyqt import widgets
from prettyqt.qt import QtWidgets


class StyleOptionFrame(widgets.StyleOptionMixin, QtWidgets.QStyleOptionFrame):
    pass
